function varargout = pointgeographic(Lat,Lon,Altitude)

%POINTGEOGRAPHIC - Geometry of Latitude, Longitude and Altitude pointing.
%G = POINTGEOGRAPHIC(LAT,LON,HGT)
%
%   LAT is latitude in degrees.
%   LON is longitude in degrees (positive).
%   HGT is altitude in km.
%
%   Example
%
%       G = pointgeographic(69,19.7,293);
%
%   Without any output argument, geometry info is printed 
%   to screen.
%
%   See also:
%
%       pointrrange, pointrheight, changersite, geom
%
%   23-Mar-2002 (c) EISCAT Scientific Association.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
if nargin ~= 3
    error('Wrong number of input arguments')
end

if ischar(Lat), Lat = str2num(Lat); end
if ischar(Lon), Lon = str2num(Lon); end
if ischar(Altitude), Altitude = str2num(Altitude); end    

G = LatLonHgt(Lat,Lon,Altitude,changersite); 
ogeom_setG(G);

if nargout == 0
    geom_print(G);
elseif nargout == 1
    varargout{1} = G;    
else
    error('Wrong number of output arguments')
end    

                                            
                                            
                                            
                                   
