function varargout = pointrrange(Az,El,Range)

%POINTRRANGE - Geometry of Azimuth, Elevation and Range pointing.
% G = POINTRRANGE(AZIM,ELEV,RANGE)
%
%   AZIM is azimuth at reference site in degrees.
%   ELEV is elevation at referense site in degrees.
%   RANGE is the required altitude of the common volume, in km.
%   The current "reference site" is used. Use the command
%   CHANGERSITE to change it. The default is 'T'.
%
%   Without any output argument, geometry info is printed 
%   to screen.
%
%   Examples
%
%       >> pointrrange 180 77.3 300 
%           ==> print to screen
%
%       >> G = pointrrange(180, 77.3, 300) 
%           ==> return info in G, show G in default format.
%
%   See also
%
%       pointrheight, pointgeographic, changersite, geom
%
%   23-Mar-2002 (c) EISCAT Scientific Association.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
if nargin ~= 3
    error('Wrong number of input arguments')
end

if ischar(Az), Az = str2num(Az); end
if ischar(El), El = str2num(El); end
if ischar(Range), Range = str2num(Range); end    

G = AzElRge(Az,El,Range,changersite);
ogeom_setG(G);
    
if nargout == 0
    geom_print(G);
elseif nargout == 1
    varargout{1} = G;    
else
    error('Wrong number of output arguments')
end    
