function A = Altitude(P)

% Returns the altitude of a point, given its geometric cartesian
% coordinates (P).
% The method is to minimize the distance between the given
% point and an arbitrary point on the spheroid. The minimum
% is found by first solving numerically (Newton's method) the
% equation for the Lagrange multiplier arising in the constrained
% extremum value problem.

A = 6378.135;
B = 6356.75;

% Initialize iteration.

RG = sqrt( P(1)*P(1) + P(2)*P(2) + P(3)*P(3) );
AA=A*A;
BB=B*B;
AAINV=1/AA;
BBINV=1/BB;
CA= AAINV * ( P(1)*P(1) + P(2)*P(2) );
CB= BBINV * P(3)*P(3);
L = B*(RG-B);
H1= RG-B; % a very simple initial guess
K=0;      % Iteration counter

% Compute height

epsi = 1e-9;

while (1)

    FA = 1/ (1+L*AAINV);                                     %   
    FB = 1/ (1+L*BBINV);                                     %       
    G = CA*FA*FA + CB*FB*FB -1;                              %
    DG = (-2)*( CA*AAINV*FA*FA*FA + CB*BBINV*FB*FB*FB);      %               
    L = L - G/DG;                                            % = GcGToGgrHgt.m
    xDif = -L*P(1)/(AA+L);                                   %
    yDif = -L*P(2)/(AA+L);                                   % 
    zDif = -L*P(3)/(BB+L);                                   %
    H2 = sqrt( xDif*xDif + yDif*yDif + zDif*zDif );          %
    K = K+1;

    if (abs(H1-H2) > epsi) 
        H1 = H2;
    %    GcCToGgrHgt;
        K = K+1;
    else
        break
    end    

end

A = H2;
