function [Pha, Amp, PolFac] = Polarizer(RX, TX)
 
% Compute EISCAT polarizer phase and amplitude for ALLX configuration,
% given transmitted and recieved complex polarization vectors 
% (expressed in polar form, e.g. RX(1:4) = (absVer, absHor, argVer, argHor)),
% with the arg angles in degrees.
% The polarizer setting is computed from formula (35) in
% the article J. Markkanen, The Sodankyla Polarizer, in EISCAT Annual
% Report 1986, (Olostunturi).
% Also compute the polarization factor PolFac == (abs(RX/TX))^2.
% (For circular TX, this would be 1-0.5 sin^2(Gamma), where
% Gamma is beam intersection angle.)


PolFac = ( RX(1)*RX(1) + RX(3)*RX(3) )/( TX(1)*TX(1) + TX(3)*TX(3) );


if  RX(3) < 1*10^(-6)
    
   Amp = 128;

else

    Amp = 80*log10( RX(1)/RX(3) );

end



Pha = RX(4)-RX(2) - 180;

% Shift Pha to 0...360 range:

while Pha < 0

    Pha = Pha + 360;
    
end

Pha = mod(Pha, 360);
