function RX = RX_Vector( TX, M )

% Map the transmitted complex polarization vector (TX) to the recieved
% polarization vector (RX), using the rotation matrix (M) from Tromso
% antenna frame to the site's antenna frame.
% RX and TX are expressed in polar form with the arguments in degrees,
% e.g.  RX(1:4) = ( absver, argVer, absHor, argHor).

DR = atan(1)/45;
RD = 1/DR;

% Put TX = (A,B,0) to cartesian form:

A1 = TX(1) * cos(TX(2)*DR);
A2 = TX(1) * sin(TX(2)*DR);
B1 = TX(3) * cos(TX(4)*DR);
B2 = TX(3) * sin(TX(4)*DR);

% Compute RX = (C,D,.) as RX = M.TX:

C1 = M(1,1)*A1 + M(1,2)*B1;
C2 = M(1,1)*A2 + M(1,2)*B2;
D1 = M(2,1)*A1 + M(2,2)*B1;
D2 = M(2,1)*A2 + M(2,2)*B2;

% Convert RX to polar form:

RX(1) = sqrt(C1*C1 + C2*C2);
RX(2) = atan2( C2, C1 ) * RD;
RX(3) = sqrt(D1*D1 + D2*D2);
RX(4) = atan2( D2, D1 ) * RD;
