function O = ogeom_calc

% From geocentric cartesian data, compute ranges etc. for all sites.

[O.azT, O.elT, O.rT] = GcCToLoc(gcP, gcT, sgTT);
[O.azK, O.elK, O.rK] = GcCToLoc(gcP, gcK, sgKK);
[O.azS, O.elS, O.rS] = GcCToLoc(gcP, gcS, sgSS);


[Lat, Lon, Hgt] = GcCToGgr(gcP);

% Compute rotation matrixes from Tromso antenna frame to remote
% antenna frames.

aaTS = Get_aaM( azT, elT, azS, elS, sgTT, sgSS );
aaTK = Get_aaM( azT, elT, azK, elK, sgTT, sgKK );

% Compute recieved (complex) polarization vectors for K and S, in
% polar form (rx1=absVer, rx2=argVer, rx3=absHor, rx4=absHor).


rxS = RX_Vector(TX, aaTS);
rxK = RX_Vector(TX, aaTK);

% Compute polarization factor (in power), and polarizer setting for ALLX.

[PhaS, AmpS, PolfS] = Polarizer(rxS, TX);
[PhaK, AmpK, PolfK] = Polarizer(rxK, TX);

% Isolate beam intersection angles

RD = 45/atan(1);

gammaS = acos(aaTS(3,3))*RD;
gammaK = acos(aaTK(3,3))*RD;

% Compute beam intersection volumes and illumination delays for remotes

Pulse = -1;

[volS, delayS] = GetVol( rT, rS, gammaS, Pulse );
[volK, delayK] = GetVol( rT, rK, gammaK, Pulse );



