function G = ogeo_calc(gcP,gcT,gcS,gcK,gcESR,sgTT,sgKK,sgSS,sgESR,TX)

%G = ogeo_calc(gcP,gcT,gcS,gcK,gcESR,sgTT,sgKK,sgSS,sgESR,TX)
%
%

%---------------------------------------------------------

% From geocentric cartesian data, compute ranges etc. for all sites.

[G.azT, G.elT, G.rT] = GcCToLoc(gcP, gcT, sgTT);
[G.azK, G.elK, G.rK] = GcCToLoc(gcP, gcK, sgKK);
[G.azS, G.elS, G.rS] = GcCToLoc(gcP, gcS, sgSS);
[G.azESR, G.elESR, G.rESR] = GcCToLoc(gcP, gcESR, sgESR);

[G.Lat, G.Lon, G.Hgt] = GcCToGgr(gcP);

% Compute rotation matrixes from Tromso antenna frame to remote
% antenna frames.

aaTS = Get_aaM( G.azT, G.elT, G.azS, G.elS, sgTT, sgSS );
aaTK = Get_aaM( G.azT, G.elT, G.azK, G.elK, sgTT, sgKK );
aaTESR = Get_aaM(G.azT, G.elT, G.azESR, G.elESR, sgTT, sgESR);

% Compute recieved (complex) polarization vectors for K and S, in
% polar form (rx1=absVer, rx2=argVer, rx3=absHor, rx4=absHor).

G.rxS = RX_Vector(TX, aaTS);
G.rxK = RX_Vector(TX, aaTK);
G.rxESR = RX_Vector(TX, aaTESR);

% Compute polarization factor (in power), and polarizer setting for ALLX.

[G.PhaS, G.AmpS, G.PolfS] = Polarizer(G.rxS, TX);
[G.PhaK, G.AmpK, G.PolfK] = Polarizer(G.rxK, TX);
[G.PhaESR, G.AmpESR, G.PolfESR] = Polarizer(G.rxESR, TX);

% Isolate beam intersection angles

RD = 45/atan(1);

G.gammaS = acos(aaTS(3,3))*RD;
G.gammaK = acos(aaTK(3,3))*RD;
G.gammaESR = acos(aaTESR(3,3))*RD;

% Compute beam intersection volumes and illumination delays for remotes

Pulse = -1;

[G.volS, G.delayS] = GetVol( G.rT, G.rS, G.gammaS, Pulse);
[G.volK, G.delayK] = GetVol( G.rT, G.rK, G.gammaK, Pulse);
[G.volESR, G.delayESR] = GetVol(G.rT, G.rESR, G.gammaESR, Pulse);


